pyxmpp2.error

Package pyxmpp2 :: Module error |
[hide private]

# Module error

XMPP error handling.

Normative reference:
  - RFC 6120
  - RFC 3920

Classes | [hide private]
| ErrorElement Base class for both XMPP stream and stanza errors
| StreamErrorElement Stream error element.
| StanzaErrorElement Stanza error element.

Variables | [hide private]
| logger = `logging.getLogger("pyxmpp.error")`
| STREAM_ERRORS = ``{``u'``bad-format``'``:` `(``'``Received XML cannot be proce``...``
| STREAM_ERRORS_Q = ``{``'``{urn:ietf:params:xml:ns:xmpp-streams}bad-f``...``
| UNDEFINED_STREAM_CONDITION = ``'``{urn:ietf:params:xml:ns:xmpp-str``...``
| UNDEFINED_STANZA_CONDITION = ``'``{urn:ietf:params:xml:ns:xmpp-sta``...``
| STANZA_ERRORS = ``{``u'``bad-request``'``:` `(``'``Bad request``'``,` `'``modify``'``)``,` `u'``...``
| STANZA_ERRORS_Q = ``{``'``{urn:ietf:params:xml:ns:xmpp-stanzas}bad-r``...``
| OBSOLETE_CONDITIONS = ``{``'``{urn:ietf:params:xml:ns:xmpp-stanzas}p``...``
| x = ``(``u'``unexpected-request``'``,` `(``'``Unexpected request``'``,` `'``wait``'``)``)``

Variables Details | [hide private]

  ### STREAM_ERRORS Value:
      {u'bad-format': ('Received XML cannot be processed'),
       u'bad-namespace-prefix': ('Bad namespace prefix'),
       u'conflict': ('Closing stream because of conflicting stream being ope
      ned'),
       u'connection-timeout': ('Connection was idle too long'),
       u'host-gone': ('Hostname is no longer hosted on the server'),
       u'host-unknown': ('Hostname requested is not known to the server'),
       u'improper-addressing': ('Improper addressing'),
      ...

  ### STREAM_ERRORS_Q Value:
      {'{urn:ietf:params:xml:ns:xmpp-streams}bad-format': ('Received XML can
      not be processed'),
       '{urn:ietf:params:xml:ns:xmpp-streams}bad-namespace-prefix': ('Bad na
      mespace prefix'),
       '{urn:ietf:params:xml:ns:xmpp-streams}conflict': ('Closing stream bec
      ause of conflicting stream being opened'),
       '{urn:ietf:params:xml:ns:xmpp-streams}connection-timeout': ('Connecti
      on was idle too long'),
      ...

  ### UNDEFINED_STREAM_CONDITION Value:
      '{urn:ietf:params:xml:ns:xmpp-streams}undefined-condition'

  ### UNDEFINED_STANZA_CONDITION Value:
      '{urn:ietf:params:xml:ns:xmpp-stanzas}undefined-condition'

  ### STANZA_ERRORS Value:
      {u'bad-request': ('Bad request', 'modify'),
       u'conflict': ('Named session or resource already exists', 'cancel'),
       u'feature-not-implemented': ('Feature requested is not implemented',
                                    'cancel'),
       u'forbidden': ('You are forbidden to perform requested action',
                      'auth'),
       u'gone': ('Recipient or server can no longer be contacted at this add
      ress',
      ...

  ### STANZA_ERRORS_Q Value:
      {'{urn:ietf:params:xml:ns:xmpp-stanzas}bad-request': ('Bad request',
                                                            'modify'),
       '{urn:ietf:params:xml:ns:xmpp-stanzas}conflict': ('Named session or r
      esource already exists',
                                                         'cancel'),
       '{urn:ietf:params:xml:ns:xmpp-stanzas}feature-not-implemented': ('Fea
      ture requested is not implemented',
                                                                        'can
      ...

  ### OBSOLETE_CONDITIONS Value:
      {'{urn:ietf:params:xml:ns:xmpp-stanzas}payment-required': '{urn:ietf:p
      arams:xml:ns:xmpp-stanzas}undefined-condition',
       '{urn:ietf:params:xml:ns:xmpp-streams}invalid-id': '{urn:ietf:params:
      xml:ns:xmpp-streams}undefined-condition',
       '{urn:ietf:params:xml:ns:xmpp-streams}xml-not-well-formed': '{urn:iet
      f:params:xml:ns:xmpp-streams}not-well-formed'}